#!/bin/bash
# Adds scrubbed taxondeterminations to VegBIEN
# Usage: make inputs/.TNRS/public.unscrubbed_taxondetermination_view/scrub-remake [wait=1]

selfDir="$(dirname -- "$0")"
selfDirName="$(basename -- "$selfDir")"

# Config
let pause=2*60*60 # sec; = 2 hr
let maxPause=4*60*60 # sec; =4 hr; must be >= max partition import time (1.5 hr)
test "$pause" -le "$maxPause" || exit -1

unset n # ($n would limit the # rows/iteration, rather than the total rows)

cd "$selfDir/.." # needed by make

make () { env make --makefile=../input.Makefile "$@"; }

log_="$(make -s "$selfDirName"/log_file)"
exec >>"$log_" 2>&1

rowsAdded ()
{
    tail -10 "$log_"|grep -E '^Inserted [1-9][0-9]* new rows into database$' \
        >/dev/null
}

let totalPause=0
while true; do
    make "$selfDirName"/import
    
    if ! rowsAdded; then
        test -n "$wait" || break
        echo "Waited $totalPause sec total"
        let 'totalPause += pause'
        test "$totalPause" -gt "$maxPause" && break
        echo "Waiting $pause sec..."
        sleep "$pause" # wait for more rows
        continue # try again
    fi
    # otherwise, rows found
    let totalPause=0
done
